import hiero
# If export is unavailable, such as when running Hiero Player, exclude the ability to submit for client review.
if ('exports' in hiero.core.env['Features']):
    import send_for_review_exporter
    from PySide2 import QtWidgets

    # XML for creating the initial 'Review Submission' preset
    PRESET_XML = """
    <root presetname="Review Submission" tasktype="hiero.exporters.FnShotProcessor.ShotProcessor">
        <startFrameIndex valuetype="int">1001</startFrameIndex>
        <exportRoot valuetype="str">{projectroot}</exportRoot>
        <versionIndex valuetype="int">1</versionIndex>
        <cutUseHandles valuetype="bool">False</cutUseHandles>
        <versionPadding valuetype="int">2</versionPadding>
        <exportTemplate valuetype="list">
            <SequenceItem valuetype="tuple">
                <SequenceItem valuetype="str">{YYYY}_{MM}_{DD}/{shot}.mov</SequenceItem>
                <SequenceItem valuetype="send_for_review_exporter.SubmitForClientReviewPreset">
                    <root presetname="send_for_review_exporter.SubmitForClientReviewExporter" tasktype="send_for_review_exporter.SubmitForClientReviewExporter">
                        <colourspace valuetype="str">default</colourspace>
                        <file_type valuetype="unicode">mov</file_type>
                        <mov valuetype="dict">
                            <b_frames valuetype="int">0</b_frames>
                            <bitrate_tolerance valuetype="int">40000000</bitrate_tolerance>
                            <gop_size valuetype="int">12</gop_size>
                            <quality_max valuetype="int">31</quality_max>
                            <quality_min valuetype="int">2</quality_min>
                            <codec valuetype="str">ap4h&#x09;Apple ProRes 4444</codec>
                            <encoder valuetype="str">mov64</encoder>
                            <bitrate valuetype="int">20000</bitrate>
                        </mov>
                        <readAllLinesForExport valuetype="bool">True</readAllLinesForExport>
                        <channels valuetype="str">rgb</channels>
                        <deleteAudio valuetype="bool">True</deleteAudio>
                        <burninDataEnabled valuetype="bool">False</burninDataEnabled>
                        <useSingleSocket valuetype="bool">False</useSingleSocket>
                        <additionalNodesEnabled valuetype="bool">False</additionalNodesEnabled>
                        <additionalNodesData valuetype="list" />
                        <publishResult valuetype="bool">True</publishResult>
                        <dpx valuetype="dict">
                            <datatype valuetype="str">8 bit</datatype>
                            <transfer valuetype="str">(auto detect)</transfer>
                            <bigEndian valuetype="bool">True</bigEndian>
                            <fill valuetype="bool">False</fill>
                        </dpx>
                        <includeEffects valuetype="bool">True</includeEffects>
                        <burninData valuetype="dict">
                            <burnIn_bottomRight valuetype="NoneType">None</burnIn_bottomRight>
                            <burnIn_topLeft valuetype="NoneType">None</burnIn_topLeft>
                            <burnIn_topMiddle valuetype="NoneType">None</burnIn_topMiddle>
                            <burnIn_padding valuetype="NoneType">None</burnIn_padding>
                            <burnIn_topRight valuetype="NoneType">None</burnIn_topRight>
                            <burnIn_bottomMiddle valuetype="NoneType">None</burnIn_bottomMiddle>
                            <burnIn_bottomLeft valuetype="NoneType">None</burnIn_bottomLeft>
                            <burnIn_textSize valuetype="NoneType">None</burnIn_textSize>
                            <burnIn_font valuetype="NoneType">None</burnIn_font>
                        </burninData>
                        <includeAudio valuetype="bool">False</includeAudio>
                        <submitThumbnails valuetype="bool">True</submitThumbnails>
                        <writeNodeName valuetype="str">Write_{ext}</writeNodeName>
                        <reformat valuetype="dict">
                            <filter valuetype="str">Cubic</filter>
                            <to_type valuetype="str">None</to_type>
                            <scale valuetype="float">1.0</scale>
                            <center valuetype="bool">True</center>
                            <resize valuetype="str">width</resize>
                        </reformat>
                        <keepNukeScript valuetype="bool">False</keepNukeScript>
                        <method valuetype="str">Blend</method>
                    </root>
                </SequenceItem>
            </SequenceItem>
        </exportTemplate>
        <excludeTags valuetype="list" />
        <includeTags valuetype="list" />
        <includeRetimes valuetype="bool">False</includeRetimes>
        <startFrameSource valuetype="str">Source</startFrameSource>
        <cutLength valuetype="bool">True</cutLength>
        <cutHandles valuetype="int">12</cutHandles>
    </root>
    """

    class SubmitForClientReviewUI(hiero.exporters.FnTranscodeExporterUI.TranscodeExporterUI):
        """Provides an interface for the exporter to update the preset's properties(), which in turn is used by the processor"""
        def __init__(self, preset):
            super(SubmitForClientReviewUI, self).__init__(preset)
            #hiero.exporters.FnTranscodeExporterUI.TranscodeExporterUI.__init__(self, preset)
            self._displayName = "Submit For Client Review"
            # link UI to processor
            self._taskType = send_for_review_exporter.SubmitForClientReviewExporter
        
        def populateUI(self, widget, exportTemplate):
            """Build the UI for tis exporter.
            widget is the parent widget that holds the UI."""

            # add default UI
            super(SubmitForClientReviewUI, self).populateUI(widget, exportTemplate)
            
            # add custom widgets and load their values from properties dict
            self.publishWidget = QtWidgets.QCheckBox()       
            self.publishWidget.setChecked(self._preset.properties()['submitThumbnails'])
            
            # add the custom widgets to the base porcessor's form layout
            self._formLayout.insertRow(0, 'Submit Thumbnails', self.publishWidget)

            # connext any signals that need connecting to make the custom widgets functional
            self.connectSignalsAndSlots()

        def connectSignalsAndSlots(self):
            self.publishWidget.stateChanged.connect(self._publishWidgetChanged)

        def _publishWidgetChanged(self, state):
            '''Save widget values in preset's properties()'''
            self._preset.properties()['submitThumbnails'] = bool(state)

    hiero.ui.taskUIRegistry.registerTaskUI(send_for_review_exporter.SubmitForClientReviewPreset, SubmitForClientReviewUI)
